/**
 * @file create_mission_XML.cpp
 * @author Gerrit Pauls (gerrit.pauls@tuhh.de)
 * @brief sets mission steps for create mission XML's standard mission
 * @version 0.1
 * @date 2024-08-30
 * 
 * @copyright Copyright (c) 2024
 * 
 */
#include <memory>
#include <map>
#include <string>
#include <vector>

#include "create_mission_xml.h"
#include <moduleBasics/module.h>
#include <moduleBasics/strategySelector.h>
#include "standard_mission/standard_mission/standard_mission.h"

/**
 * @brief Construct a new create_mission_xml:: create_mission_xml object
 * 
 * @param toolName entry from toolinfo.h
 * @param toolVersion entry from toolinfo.h
 */
create_mission_xml::create_mission_xml(const int argc, char *argv[], const std::string &toolName,
                                 const std::string &toolVersion)
  : Module(argc, argv, toolName, toolVersion) {
  std::string mission_choice = "standard";//std::string(rtIO_->acxml.at("program_settings/mission_choice/value"));
  route_ = {mission_choice}; // By now, only one level depth vector
  missionStrategy_.setStrategy(missionSelection_(route_)(rtIO_));
}

strategyaccess create_mission_xml::missionSelection_(const std::vector<std::string> &route) {
    /* Routing table */
    std::map<std::string, strategyaccess> table = {
        {"standard", [](const std::shared_ptr<RuntimeIO>& arg) { return std::make_unique<standard_mission>(arg); }},
        {"placeholder_1", [](const std::shared_ptr<RuntimeIO>& arg) { return std::make_unique<standard_mission>(arg); }},
        {"placeholder_2", [](const std::shared_ptr<RuntimeIO>& arg) { return std::make_unique<standard_mission>(arg); }}
  };
  return table[route.at(0)];
}
