/**
 * \file ecological_assessment.cpp
 * \author Katrin Bistreck (katrin.bistreck@tuhh.de)
 * \brief Base module for ecological_assessment
 * \version 1.0
 * \date 2023-10-19
 *
 * @copyright Copyright (c) 2023
 *
 */
#include <string>
#include <vector>
#include <memory>
#include <filesystem>
#include <iostream>
#include <map>

#include <moduleBasics/module.h>
#include <moduleBasics/strategySelector.h>
#include <aixml/node.h>
#include <runtimeInfo/runtimeInfo.h>
#include "ecological_assessment.h"
#include "standard_strategy/standard_strategy.h"

namespace fs = std::filesystem;

/**
 * @brief Construct a new EcologicalAssessment:: EcologicalAssessment object
 *
 * @param toolName entry from toolinfo.h
 * @param toolVersion entry from toolinfo.h
 */
EcologicalAssessment::EcologicalAssessment(const int argc, char *argv[], const std::string &toolName, const std::string &toolVersion)
    : Module(argc, argv, toolName, toolVersion) {
  rtIO_ = get_RuntimeIO();

  /* Set strategy route (by now, only one standard strategy exists which offers the possibility to use different methods) */
  std::string strategy_name(rtIO_->moduleConfig.at("program_settings/strategy_selector/value"));
  route_ = {strategy_name};
  strategy_.setStrategy(routing_(route_)(rtIO_));
}

strategyaccess EcologicalAssessment::routing_(const std::vector<std::string> &route) {
  /* Routing table for ecological assessment */
  std::map<std::string, strategyaccess> table = {
      {"STANDARD", [](const std::shared_ptr<RuntimeIO>& arg) { return std::make_unique<StandardStrategy>(arg);}},
  };
  return table[route.at(0)];
}

