/**
 * \file ecological_assessment.h
 * \author Katrin Bistreck (katrin.bistreck@tuhh.de)
 * \brief Base module for ecological assessment
 * \version 1.0
 * \date 2023-10-19
 *
 * @copyright Copyright (c) 2023
 *
 */
#ifndef ECOLOGICAL_ASSESSMENT_SRC_ECOLOGICAL_ASSESSMENT_H_
#define ECOLOGICAL_ASSESSMENT_SRC_ECOLOGICAL_ASSESSMENT_H_

#include "aixml/node.h"
#include <moduleBasics/module.h>
#include <moduleBasics/report.h>
#include <moduleBasics/strategySelector.h>
#include <aixml/endnode.h>
#include <string>
#include <vector>
#include <memory>

/** \class EcologicalAssessment
 * \brief Base class for ecological assessment
 */
class EcologicalAssessment : public Module {
 public:
 /** \brief Constructor of class EcologicalAssessment
  * \param argc The number of command line arguments.
  * \param argv The command line arguments.
  * \param toolName The name of the tool.
  * \param toolVersion The version of the tool.
  */
  EcologicalAssessment(const int argc, char *argv[], const std::string &toolName, const std::string &toolVersion);
  EcologicalAssessment(const std::string& toolName, const std::string& toolVersion, const std::filesystem::path& rtConfigCML)
      : Module(toolName, toolVersion, rtConfigCML) {}
  /** \brief Destructor of EcologicalAssessment object
   */
  ~EcologicalAssessment() = default;

  void initialize() override { strategy_.initializeStrategy(); }
  void run() override { strategy_.runStrategy(); };
  void update() override { strategy_.updateStrategy(); };
  void report() override { strategy_.reportStrategy(); };
  void save() override { strategy_.saveStrategy(); rtIO_->saveAndCloseAcXML(); rtIO_->closeModuleConfig(); };

 private:
  std::vector<std::string> route_; /**< Routing for strategy*/
  strategyaccess routing_(const std::vector<std::string> &route); /**< Strategy access */
  StrategySelector strategy_; /**< Strategy */
};


#endif // ECOLOGICAL_ASSESSMENT_SRC_ECOLOGICAL_ASSESSMENT_H_
