/**
 * \file missionConfig.cpp
 * \author Katrin Bistreck (katrin.bistreck@tuhh.de)
 * \brief configuration class for reading schaefer data from conf.xml
 * \version 0.1
 * \date 2023-12-04
 *
 * @copyright Copyright (c) 2023
 *
 */

#include "missionConfig.h"
#include <aixml/node.h>

using std::string;

MissionConfig::MissionConfig()
    :
    keroseneMethodHC(""),
    kersoseneMethodCO(""),
    keroseneMethodNOx(""),
    keroseneMethodSoot(""),
    relativeHumidity(0.) {}

void MissionConfig::readAllConfigData(const node& configXML) {
    const node& mission(configXML.at("program_settings/standard_strategy/emission_calculation/mission_emissions"));

    keroseneMethodHC = EndnodeReadOnly<string>("emission_methods/kerosene/HC_method_selector").read(mission).value();
    kersoseneMethodCO = EndnodeReadOnly<string>("emission_methods/kerosene/CO_method_selector").read(mission).value();
    keroseneMethodNOx = EndnodeReadOnly<string>("emission_methods/kerosene/NOx_method_selector").read(mission).value();
    keroseneMethodSoot = EndnodeReadOnly<string>("emission_methods/kerosene/soot_method_selector").read(mission).value();
    hydrogenMethodNOx = EndnodeReadOnly<string>("emission_methods/hydrogen_combustion/NOx_method_selector").read(mission).value();
    relativeHumidity = EndnodeReadOnly<double>("relative_humidity").read(mission).value();
}

MissionConfig::~MissionConfig() {
    //dtor
}

