/**
 * \file emissionsClass.h
 * \author Katrin Bistreck (katrin.bistreck@tuhh.de)
 * \brief Provides list of emissions and potentials
 * \version 0.1
 * \date 2023-08-28
 *
 * @copyright Copyright (c) 2023
 *
 */

#ifndef ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_EMISSIONSCLASS_H_
#define ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_EMISSIONSCLASS_H_

/** \class Emissions
 * \brief Class contains emissions and potentials
 */
class Emissions {
 public:
    /*Emissions*/
    double CO2; /**< Carbon dioxide [kg]*/
    double H2O;/**< Water emission [kg]*/
    double NOx;/**< Nitrogen oxides [kg]*/
    double CO;/**< Carbon monoxide [kg]*/
    double SO2;/**< Sulphur dioxide [kg]*/
    double SO4;/**<Optically active sulfate [kg] */
    double CH4;/**< Methane [kg]*/
    double PM10;/**< Particulate matter (for mission: it is assumed that PM consists only of soot -> PM10 = soot) [kg]*/
    double soot; /**< Soot [kg] */
    double N2O;/**< Nitrous oxide (laughing gas) [kg]*/
    double PFC;/**< Perfluorinated hydrocarbons [kg]*/
    double NMVOC;/**< Non methane volatile organic compounds [kg]*/
    double HC; /**< Hydrocarbon [kg]*/

    /*Potentials*/
    double GWP100;/**< Global Warming Potential for a 100 year time frame [1/MJ] or [1/kg]*/
    double AP;/**< Acidification Potential [1/MJ] or [1/kg]*/
    double ADP;/**< Abiotic Resource Depletion Potential [1/MJ] or [1/kg]*/
    double POCP;/**< Photochemical Ozone Creation Potential [1/MJ] or [1/kg] */
    double OLDP;/**< Ozone Layer Depletion Potential [1/MJ] or [1/kg] */
    double PMFP;/**< Particulate Matter Formation Potential [1/MJ] or [1/kg] */
    double CED;/**< Cumulative Energy Demand [MJ]*/

    /** \brief Constructor of class Emissions
     */
    Emissions();

    /** \brief Destructor of class Emissions
     */
    virtual ~Emissions() {}
};

#endif // ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_EMISSIONSCLASS_H_
