/**
 * \file AQI_Schaefer.h
 * \author katrin.bistreck@tuhh.de
 * \brief Header of submodule for air quality index calculation
 * \version 0.1
 * \date 2023-11-25
 *
 * @copyright Copyright (c) 2023
 *
 */
#ifndef ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_IMPACT_CALCULATION_AIR_QUALITY_INDEX_SCHAEFER_AQI_SCHAEFER_H_
#define ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_IMPACT_CALCULATION_AIR_QUALITY_INDEX_SCHAEFER_AQI_SCHAEFER_H_

#include <memory>
#include <vector>
#include <string>
#include <moduleBasics/runtimeIO.h>
#include <atmosphere/atmosphere.h>
#include <aixml/node.h>
#include "AQISchaeferIOData.h"

/** \class AQISchaefer
 * \brief Class for air quality index calculation accordign to Schaefer (2017) \cite Sch17
 */
class AQISchaefer {
 public:
    /** \brief Constructor of class AQISchaefer
     */
    AQISchaefer();
    /** \brief Destructor of class AQISchaefer */
    ~AQISchaefer() = default;

    /** \brief Function to run Schaefer AQI method
     * \param rtIO Access to rtIO
     * \param ecoAssXML Pointer to node of ecological assessment results
     */
    void run(const std::shared_ptr<RuntimeIO> &rtIO, std::shared_ptr<node> ecoAssXML);

    /** \brief Function to calculate the air quality index according to Schaefer (2017) \cite Sch17
    */
    void calculateAQISchaefer(const std::string &fuelType);

    atmosphere myAtm;/**< Atmosphere object */
    std::shared_ptr<AQISchaeferIOData> AQISchaeferIOData_; /**< Pointer to ioData */
    double Tolerance_CO;/**< Tolerance factors of CO emissions emitted during LTO [-] */
    double Tolerance_HC;/**< Tolerance factors of HC emissions emitted during LTO [-] */
    double Tolerance_NOx;/**< Tolerance factors of NOx emissions emitted during LTO [-] */
    double Tolerance_soot;/**< Tolerance factors of soot emissions emitted during LTO [-] */
    double AQI;/**< AIr quality index [-] */
};

#endif //ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_IMPACT_CALCULATION_AIR_QUALITY_INDEX_SCHAEFER_AQI_SCHAEFER_H_
