/**
 * \file schaeferConfig.h
 * \author Katrin Bistreck (katrin.bistreck@tuhh.de)
 * \brief configuration class for reading schaefer data from conf.xml
 * \version 0.1
 * \date 2023-12-04
 *
 * @copyright Copyright (c) 2023
 *
 */

#ifndef ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_IMPACT_CALCULATION_CLIMATE_MODEL_DALLARA_DALLARACONFIG_H_
#define ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_IMPACT_CALCULATION_CLIMATE_MODEL_DALLARA_DALLARACONFIG_H_

#include <string>
#include <aixml/endnode.h>
#include "../../emissionsClass.h"

/** \class DallaraConfig
 * \brief Class for the config settings needed for dallara strategy
*/
class DallaraConfig {
 public:
    //aigner: New Factors to account for variations in s_i_height
    //(Reference Dallara --> forcing factors (s_i_height) have a 66% likelihood range
    double s_i_heightVariation_AIC;/**< Variable for variation of AIC forcing factor [-]*/
    double s_i_heightVariation_O3S;/**< Variable for variation of O3S forcing factor [-]*/
    double s_i_heightVariation_CH4O3L;/**< Variable for variation of CH4O3L forcing factor [-]*/
    /*Climate effect input parameters*/
    double fuelAICfactor;/**<Factor to vary the impact of aircraft induced cloudiness (min: 0.3, max 0.8) [-]*/
    std::string s_i_dataSet;/**<Data set for forcing factor calculation. 'mode_0': Dallara 2011, 'mode_1': Dahlmann 2011*/
    int tmax;/**<Considered timeframe [yr] */
    double devRate;/**<Devaluation rate of the temperature response [-]*/
    int durationOperation; /**< Duration of the operating phase [yr] */

    /** \brief Default constructor of class DallaraConfig
     */
    DallaraConfig();

    /** \brief Destructor of class SchaeferIOData
     */
    virtual ~DallaraConfig();

    /** \brief Function to read schaefer specific data from ecological_assessment.xml
     * \param config node of the data structure defined by config file
     */
    void readAllConfigData(const node& config);

 private:
    /** \brief Function to read devlopment data from conig.xml
     * \param forcingFactor node of the forcingFactor in config file
     */
    void readForcingFactorConfigData(const node& forcingFactor);
};

#endif // ECOLOGICAL_ASSESSMENT_SRC_STANDARD_STRATEGY_IMPACT_CALCULATION_CLIMATE_MODEL_DALLARA_DALLARACONFIG_H_
