/**
 * \file bwbVerticalTailsConfig.cpp
 * \author Christopher Ruwisch (christopher.ruwisch@tu-berlin.de)
 * \brief Blended Wing Body Vertical Tails Config source file
 * \version 0.1
 * \date 2024-04-17
 *
 * @copyright Copyright (c) 2024
 *
 */

#include "bwbVerticalTailsConfig.h"

#include <aircraftGeometry2/airfoil_surface.h>

namespace bwb {
namespace low {
VerticalTailsConfig::VerticalTailsConfig()
    : design_mode(EndnodeReadOnly<std::string>("module_configuration_file/program_settings/modes/design_mode")),
      mass_mode(EndnodeReadOnly<std::string>("module_configuration_file/program_settings/modes/mass_mode/method")),
      mass_mode_flops_technology_factor(EndnodeReadOnly<double>("module_configuration_file/program_settings/modes/mass_mode/parameters/mode_0/technology_factor")) {}

void VerticalTailsConfig::read(const node& xml) {
  design_mode.read(xml);
  mass_mode.read(xml);
  mass_mode_flops_technology_factor.read(xml);

  /* List all tail elements */
  std::string path_to_tail_elements =
      "module_configuration_file/program_settings/blended_wing_body/low_fidelity/vertical_tails/tail_element";
  std::vector<node*> tail_elements = xml.getVector(path_to_tail_elements, 1);
  for (size_t id = 0; id < tail_elements.size(); ++id) {
    vertical_tails.push_back(TailElement(path_to_tail_elements + "@" + std::to_string(id) + "/"));
  }
  for (auto& vertical_tail : vertical_tails) {
    vertical_tail.read(xml);
  }
}
}  // namespace low
}  // namespace bwb
