/**
 * \file bwbVerticalTailsData.h
 * \author Christopher Ruwisch (christopher.ruwisch@tu-berlin.de)
 * \brief Blended Wing Body Vertical Tails Data header file
 * \version 0.1
 * \date 2024-04-17
 *
 * @copyright Copyright (c) 2024
 *
 */
#ifndef EMPENNAGEDESIGN_SRC_BWB_VERTICALTAILSDATA_H_
#define EMPENNAGEDESIGN_SRC_BWB_VERTICALTAILSDATA_H_

#include <aircraftGeometry2/geometry/factory.h>
#include <aircraftGeometry2/io/convert.h>

#include "lib/IO_methods/massPropertiesIO.h"
#include "lib/IO_methods/positionIO.h"

namespace bwb {
namespace low {

class VerticalTailsData {
 public:
  VerticalTailsData();

  void read(const node& xml);
  void read_wing(std::filesystem::path path, std::filesystem::path airfoil_data_dir);

  void update(node& xml);
  void update_vertical_tails(node& xml);

  std::vector<geom2::MultisectionSurface<geom2::AirfoilSection>> tails;
  std::vector<geom2::MultisectionSurface<geom2::PolygonSection>> controls;
  std::vector<geom2::MultisectionSurface<geom2::PolygonSection>> spars;
  std::vector<MassPropertiesIO> tails_mass;
  MassPropertiesIO empennage_mass;
  PositionIO empennage_position;

  geom2::MultisectionSurface<geom2::AirfoilSection> wing;
  MassPropertiesIO maximum_takeoff_mass;
  PositionIO wing_reference_position;
};
}  // namespace low
}  // namespace bwb

#endif  // EMPENNAGEDESIGN_SRC_BWB_VERTICALTAILSDATA_H_
