# Import standard modules.
import numpy as np
from matplotlib import pyplot as plt


def plot_fuselage_design(paths_and_names, fuselage_design, runtime_output):
    """ Generates a 3D fuselage shape design plot.

        :param dict paths_and_names: Dictionary containing system paths and ElementTrees
        :param dict fuselage_design: Dict containing the description of the fuselage shape ellipses
        :param logging.Logger runtime_output: Logging object used for capturing log messages in the module
        :return none
    """
    ''' initialize local parameter '''
    alpha_value = 0.3
    shape_color = 'grey'
    plot_title = '3D_shape'
    project_directory = paths_and_names["project_directory"]
    plot_directory = project_directory + '/reporting/plots'
    cockpit_section = fuselage_design['cockpit_section']
    tail_section = fuselage_design['tail_section']

    fig = plt.figure(figsize=(12, 7.5))
    ax = fig.add_subplot(111, projection='3d')

    # plot cockpit section
    list_x_coordinates = []
    list_y_coordinates = []
    list_z_upwards_coordinates = []
    list_z_downwards_coordinates = []
    x_direction_coordinates = cockpit_section['x_direction_coordinates']
    y_direction_coordinates = cockpit_section['y_direction_coordinates']
    z_upwards_coordinates = cockpit_section['z_upward_coordinates']
    z_downwards_coordinates = cockpit_section['z_downward_coordinates']

    i = 0
    while i < len(x_direction_coordinates):
        list_x_coordinates.append(np.array(x_direction_coordinates['ellipse_number_' + str(i + 1)]) * 2.54 / 100)
        list_y_coordinates.append(np.array(y_direction_coordinates['ellipse_number_' + str(i + 1)]) * 2.54 / 100)
        list_z_upwards_coordinates.append(np.array(z_upwards_coordinates['ellipse_number_' + str(i + 1)]) * 2.54 / 100)
        list_z_downwards_coordinates.append(np.array(z_downwards_coordinates['ellipse_number_' + str(i + 1)])
                                            * 2.54 / 100)

        i += 1

    # plot tail section
    x_direction_coordinates = tail_section['x_direction_coordinates']
    y_direction_coordinates = tail_section['y_direction_coordinates']
    z_upwards_coordinates = tail_section['z_upward_coordinates']
    z_downwards_coordinates = tail_section['z_downward_coordinates']

    i = 0
    while i < len(x_direction_coordinates):
        list_x_coordinates.append(np.array(x_direction_coordinates['ellipse_number_' + str(i + 1)]) * 2.54 / 100)
        list_y_coordinates.append(np.array(y_direction_coordinates['ellipse_number_' + str(i + 1)]) * 2.54 / 100)
        list_z_upwards_coordinates.append(np.array(z_upwards_coordinates['ellipse_number_' + str(i + 1)]) * 2.54 / 100)
        list_z_downwards_coordinates.append(np.array(z_downwards_coordinates['ellipse_number_' + str(i + 1)])
                                            * 2.54 / 100)

        i += 1

    ax.plot_surface(np.array(list_x_coordinates), np.array(list_y_coordinates),
                    np.array(list_z_upwards_coordinates), alpha=alpha_value, color=shape_color)
    ax.plot_surface(np.array(list_x_coordinates), np.array(list_y_coordinates),
                    np.array(list_z_downwards_coordinates), alpha=alpha_value, color=shape_color)

    ax.set_xlabel('fuselage length in meter', labelpad=60)

    ax.set_yticks([])
    ax.set_zticks([])
    ax.set_box_aspect((np.ptp(list_x_coordinates), np.ptp(list_y_coordinates), np.ptp(list_z_upwards_coordinates)))

    ax.view_init(30, 240)
    #plt.show()

    """ Save figures to current aircraft project directory. """
    # Save as *.svg
    tool_name = paths_and_names['tool_name']
    name_of_fig = tool_name + '_' + plot_title + '.svg'
    plt.savefig(plot_directory + '/' + name_of_fig, transparent=True)
    # Save as *.pdf
    name_of_fig = tool_name + '_' + plot_title + '.pdf'
    plt.savefig(plot_directory + '/' + name_of_fig, transparent=True)

    ''' debug print '''
    runtime_output.debug('Debug: The cockpit_section_calculation function was successfully executed!')

    return
