/*  Copyright (C) 2012-2022 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/
#include "performance_assessment.h"

#include <vector>
#include <map>
#include <memory>

#include "taw/defaultMethods/performance_assessment_factory.h"

performance_assessment::performance_assessment(const int argc, char *argv[], const std::string& toolName, const std::string& toolVersion) : Module(argc, argv, toolName, toolVersion) {
    std::string configuration = rtIO_->aircraft_configuration_type();
    std::string strategySelectionByUser = rtIO_->moduleConfig.at("/module_configuration_file/program_settings/module_strategy");
    std::string fidelitySelectionByUser = rtIO_->moduleConfig.at("/module_configuration_file/program_settings/module_fidelity_level");

    route = {configuration, strategySelectionByUser, fidelitySelectionByUser};
    strategy.setStrategy(design_routing(route)(rtIO_));
}

strategyaccess performance_assessment::design_routing(const std::vector<std::string> &route) {
    /* Routing table */
  std::map<std::string, std::map<std::string, std::map<std::string, strategyaccess>>> table = {
    {"tube_and_wing",
       std::map<std::string, std::map<std::string, strategyaccess>>{
           {"default_methods",
            std::map<std::string, strategyaccess>{
                {"low",
                 [](const std::shared_ptr<RuntimeIO> &arg) { return std::make_unique<taw::performance_assessment_factory>(arg); }},
            }},
       }},
    {"blended_wing_body",
       std::map<std::string, std::map<std::string, strategyaccess>>{
           {"default_methods",
            std::map<std::string, strategyaccess>{
                {"low",
                 [](const std::shared_ptr<RuntimeIO> &arg) { return std::make_unique<taw::performance_assessment_factory>(arg); }},
            }}}}};

  return table[route.at(0)][route.at(1)][route.at(2)];
}
