/*  Copyright (C) 2012-2022 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/

#ifndef performance_assessment_SRC_TAW_DEFAULTMETHODS_CEILINGPERFORMANCE_ABSTRACTCEILINGPERFORMANCE_H_
#define performance_assessment_SRC_TAW_DEFAULTMETHODS_CEILINGPERFORMANCE_ABSTRACTCEILINGPERFORMANCE_H_

#include <vector>

class abstractCeilingPerformance
{
 public:
    virtual ~abstractCeilingPerformance() { }
    virtual void doCeilingCalculation() = 0;

    /**\class dataCeiling Class that contains aircraft ceiling at different aircraft masses
    *
    */
    class dataCeiling {
     public:
        double Mass; /**< Aircraft mass (kg) */
        double Mach; /**< Aircraft Mach number (-) */
        double serviceCeiling; /**< Aircraft service ceiling (m) */
        double maxCeiling; /**< Aircraft maximum ceiling (m) */
        double maxCeilingOEI; /**< Aircraft maximal ceiling with one engine inoperative (m) */

        dataCeiling() {
            Mass = 0.0;
            Mach = 0.0;
            serviceCeiling = 0.0;
            maxCeiling = 0.0;
            maxCeilingOEI = 0.0;
        }
    };
    std::vector<dataCeiling> theCeiling; /**< List of the ceiling data */

};


#endif  // performance_assessment_SRC_TAW_DEFAULTMETHODS_CEILINGPERFORMANCE_ABSTRACTCEILINGPERFORMANCE_H_
