/*  Copyright (C) 2012-2022 Institute of Aerospace Systems, RWTH Aachen University - All rights reserved.
    This file is part of UNICADO.

    UNICADO is free software: you can redistribute it and/or modify
    it under the terms of the GNU General Public License as published by
    the Free Software Foundation, either version 3 of the License, or
    (at your option) any later version.

    UNICADO is distributed in the hope that it will be useful,
    but WITHOUT ANY WARRANTY; without even the implied warranty of
    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
    GNU General Public License for more details.

    You should have received a copy of the GNU General Public License
    along with UNICADO.  If not, see <http://www.gnu.org/licenses/>.
*/
#ifndef performance_assessment_SRC_TAW_DEFAULTMETHODS_LANDINGPERFORMANCE_LOW_FIDELITY_LANDINGPERFORMANCE_H_
#define performance_assessment_SRC_TAW_DEFAULTMETHODS_LANDINGPERFORMANCE_LOW_FIDELITY_LANDINGPERFORMANCE_H_

#include <runtimeInfo/runtimeInfo.h>
#include <unitConversion/unitConversion.h>
#include <vector>
#include <memory>

#include "../../aircraft.h"
#include "../abstractLandingPerformance.h"

class aircraft;

using std::vector;

namespace low {

/**\class landingPerformance Class contains the landing performance data
*
*/
class landingPerformance :public abstractLandingPerformance {
 public:
    // /**\class dataLND Class contains data about the landing
    // *
    // */
    // class dataLDN {
    //  public:
    //     /** \brief Allowed landing distance with all engines operating and MLM
    //      *  \details landing distance required including 60% safety margin (EASA: 60 percent of maximum available runway length) (m)
    //      */
    //     double ALD_AEO;
    //     double grossMass; /**< Aircraft mass (kg) */

    //     dataLDN() {
    //         ALD_AEO = 0.0;
    //         grossMass = 0.0;
    //     }
    // };

    // /**\class dataElevationLDN Class contains landing parameters for different elevations
    // *
    // */
    // class dataElevationLDN {
    //  public:
    //     double elevation; /**< Elevation (m) */
    //     vector<dataLDN> myLDN; /**< List of landing data (time, mass, landing distance) */

    //     dataElevationLDN() {
    //         elevation = 0.0;
    //     }
    // };
    // vector<dataElevationLDN> myLDNField; /**< List of elevation at landing data */

    /**\brief Function to calculate the landing distance for different altitudes and aircraft masses
    *\param theRunwaySlope Slope of the runway (rad)
    *\param theGroundFrictionBraking Friction coefficient at full braking (-)
    *\param theHeadWind Head wind speed (m/s)
    */
    void doLandingPerformance(double theRunwaySlope, double theGroundFrictionBraking, double theHeadWind) override;

    /**\brief Constructor for the landingPerformance object
    *\param theAircraft Address to the aircraft object
    */
    explicit landingPerformance(std::shared_ptr<aircraft> theAircraft);

    /**\brief Destructor of the landingPerformance object
    *
    */
    virtual ~landingPerformance();

 private:
    std::shared_ptr<aircraft> theAcftPt; /**< Pointer to theAircraft object */

    double runwaySlopeAngle; /**< Slope of the runway (rad) */
    double brakingFriction; /**< Friction coefficient for complete stop (-) */
    double windSpeed; /**< Wind speed (m/s) */

    /**\brief Function to calculate the available landing distance
    *   \param landingDistanceRequired double*: Pointer to current landing distance for dry runway at ISA+deltaISA [m]
    *   \param acMass Aircraft mass (kg)
    *   \param Altitude Airfield (aircraft) altitude (m)
    */
    void calcALD(double* landingDistanceRequired, const double& acMass, const double& Altitude);

    /**\brief Function to calculate the deceleration on ground
    *\param mass Aircraft mass (kg)
    *\param alt Aircraft altitude (m)
    *\param Velocity Aircraft speed (m/s)
    *\return Deceleration of the aircraft on ground (m/s^2)
    */
    double calcDeAccelerationGroundRoll(double mass, double alt, double Velocity);

    /**\brief Function  verifies if the landing distance can be maintained
    *\return True or false
    */
    bool checkForLDN();

    /**\brief Function verifies if the approach speed can be maintained
    *\return True or false
    */
    bool checkForApproachSpeed();

    /**\brief Function verifies if in case of missed approach the required gradient of climb with one engine inoperative can be maintained
    *\return True or false
    */
    void checkForApproachClimb();
};
}  // namespace low

#endif  // performance_assessment_SRC_TAW_DEFAULTMETHODS_LANDINGPERFORMANCE_LOW_FIDELITY_LANDINGPERFORMANCE_H_

