# Tank design method of TU Berlin

## Module structure
'main.py' runs the following functions:
1. 'data_preprocessing' (from 'datapreprocessing.py')<sup>1</sup>
   - 1.1  
2. 'run_module' (from 'methodexecutionpackage' library)<sup>2</sup>
   - 2.1
3. 'data_postprocessing' (from 'datapostprocessing.py')<sup>3</sup>

<sup>1</sup> data preprocessing runs: \
<sup>2</sup> \
<sup>3</sup> data_postprocessing runs: ...

...


### Routing layers
The tank design module has the following layer structure:

1. Aircraft configuration
   - Implemented: 'tube_and_wing'
   - Not yet implemented: 'blended_wing_body'
2. Calculation method fidelity
   - Implemented: 'empirical'
3. Calculation method
   - Implemented: 'tank_design_tu_berlin'
4. Energy carrier <sup>1</sup>
   - Implemented: 'kerosene', 'liquid_hydrogen'
   - Not yet implemented: 'hybrid'

<sup>1</sup> The used energy carrier is determined automatically in the 'read_energy_carrier_and_tank_configuration' function.

### Folder structure and overview
The 'tank_design_tu_berlin' folder contains the 'usermethoddatapreparation.py' file as well as a 'general' folder and a folder for each possible energy carrier (kerosene, liquid hydrogen, or hybrid).
- 'general'
  - The 'tankdesigntuberlin.py' module provides calculating functions for the tank design of tube-and-wing aircraft according to TU Berlin.
  - Method output functions ('methodhtmlreport.py', 'methodplot.py', 'methodtexoutput.py', and 'methodxmlexport.py'): General information on those files can be found on this [site](https://unicado.ilr.rwth-aachen.de/w/software_maintenance/how_to_python_in_unicado/).
  - The 'call_functions' folder contains all functions that are called independent of the used energy carrier.
     - '_00_readenergycarrierandtankconfiguration.py': Determine energy carrier dependent parameter.

## Data preprocessing
If the energy carrier is 'liquid_hydrogen', is is required to add information on at least **two** tanks to the aircraft exchange file, e.g.:
```
<tank_configuration description="Energy tanks information">
    <tank ID="0" description="One Tank">
        <energy_carrier_ID description="see energy carrier specification node">
            <value>0</value>
            <unit>1</unit>
            <lower_boundary>0</lower_boundary>
            <upper_boundary>5</upper_boundary>
        </energy_carrier_ID>
        <location description="Component where the tank is located: fuselage, wing, horizontal_stabilizer">
            <value>fuselage</value>
        </location>
        <position description="Position of tank in location: tailcone, rear, front, top, bottom, center, inner_left, outer_left, inner_right, outer_right, total">
            <value>tailcone</value>
        </position>
        <energy_share description="Share of this tanks energy in relation to required mission energy (of same energy carrier).">
            <value>0</value>
            <unit>1</unit>
            <lower_boundary>0.0</lower_boundary>
            <upper_boundary>1.0</upper_boundary>	
        </energy_share>
    </tank>
    <tank ID="1" description="One Tank">
        <energy_carrier_ID description="see energy carrier specification node">
            <value>0</value>
            <unit>1</unit>
            <lower_boundary>0</lower_boundary>
            <upper_boundary>5</upper_boundary>
        </energy_carrier_ID>
        <location description="Component where the tank is located: fuselage, wing, horizontal_stabilizer">
            <value>fuselage</value>
        </location>
        <position description="Position of tank in location: tailcone, rear, front, top, bottom, center, inner_left, outer_left, inner_right, outer_right, total">
            <value>rear</value>
        </position>
        <energy_share description="Share of this tanks energy in relation to required mission energy (of same energy carrier).">
            <value>0</value>
            <unit>1</unit>
            <lower_boundary>0.0</lower_boundary>
            <upper_boundary>1.0</upper_boundary>	
        </energy_share>
    </tank>
</tank_configuration>
```
For the dimensioning of the hydrogen tanks, the percentage of energy to be contained in the respective tanks must be specified. Therefore the value 'energy_share' was introduced. 

If one of those two tanks is located in the tailcone of the fuselage, the value of the 'energy_share' is not used for the calculation since it is not known beforehand how much energy the cone can hold. The same applies for kerosene driven configurations.

### Possible tank configurations for kerosene driven aircraft
The following table provides an overview on possible tank location and position combinations.
| No. |    Location   |    Position   |         Status        |                       Note                      |
| --- | ------------- | ------------- | --------------------- | ----------------------------------------------- |
|  1  | Wing          | Center        | Implemented           | |
|  2  | Wing          | Inner left    | Implemented           | |
|  3  | Wing          | Outer left    | Implemented           | |
|  4  | Wing          | Inner right   | Implemented           | |
|  5  | Wing          | Outer right   | Implemented           | |
|  6  | Horizontal stabilizer | Total | Not yet implemented   | |
|  7  | Fuselage      | Center        | Not yet implemented   | Referred to as 'Additional center tank'         |

The following table provides an overview on possible tank configurations.
|  Tank 1 |             Tank 2            |             Tank 2            |           Configuration name             |
| ------- | ----------------------------- | ----------------------------- | ---------------------------------------- |
| Wing    |               -               |               -               | wing_all_tanks                           |
| Wing    | Horizontal stabilizer - Total |               -               | wing_with_trim_tank                      |
| Wing    | Fuselage - Center             |               -               | wing_with_additional_center_tank         |
| Wing    | Horizontal stabilizer - Total | Fuselage - Center             | wing_with_additional_center_and_trim_tank|


Note: "Wing" always refers to either the combinations 1 to 5.

### Possible tank configurations for liquid hydrogen driven aircraft
The following table provides an overview on possible tank configurations for **liquid hydrogen** driven aircraft.
Please note that at least two tanks must be defined.

|    Location   |    Position   |         Status        |                       Note                      |
| ------------- | ------------- | --------------------- | ----------------------------------------------- |
| Fuselage      | Tailcone      | Implemented           | If chosen, the value 'energy_share' is not used.|
| Fuselage      | Rear          | Implemented           | |
| Fuselage      | Front         | Not yet implemented   | |
| Fuselage      | Top           | Not yet implemented   | |
| Fuselage      | Bottom        | Not yet implemented   | |
| Wing          | Pods          | Not yet implemented   | |

## Run module

## Data postprocessing