/**
 * \file aspectRatioMethods.cpp
 * \author Christopher Ruwisch (christopher.ruwisch@tu-berlin.de)
 * \brief Aspect ratio methods
 * \version 0.1
 * \date 2023-12-19
 *
 * @copyright Copyright (c) 2023
 *
 */

#include "aspectRatioMethods.h"

#include <cmath>
#include <functional>
#include <iostream>
#include <map>

double user_defined::aspect_ratio(const double user_aspect_ratio) { return user_aspect_ratio; }

double by_pitch_up_limit_function::aspect_ratio(const double sweep_at_quarter_chord) {
  return -8.5 * log(sweep_at_quarter_chord) + 5.875;  // empirical function
}

double get_design_aspect_ratio(modes aspect_ratio_mode, const double user_aspect_ratio,
                               const double quarter_chord_sweep) {
  std::map<modes, std::tuple<std::string, std::function<double(void)>>> aspect_ratio_selection = {
      {"mode_0", {"user_defined", [=]() { return user_defined::aspect_ratio(user_aspect_ratio); }}},
      {"mode_1", {"by_pitch_up_limit_function", [=]() {
                    return by_pitch_up_limit_function::aspect_ratio(quarter_chord_sweep);
                  }}}};
  const auto [method, aspect_ratio_method] = aspect_ratio_selection[aspect_ratio_mode];
  double aspect_ratio = aspect_ratio_method();
  std::cout << "Wing aspect ratio [method]: " << method << "\n";
  std::cout << "Wing aspect ratio  [value]: " << aspect_ratio << " [1]\n";
  return aspect_ratio;
}