/**
 * \file relativePositionIO.h
 * \author Christopher Ruwisch (christopher.ruwisch@tu-berlin.de)
 * \brief Relative Position IO
 * \version 0.1
 * \date 2024-01-11
 *
 * @copyright Copyright (c) 2024
 *
 */
#ifndef RELATIVE_POSITION_IO_H_
#define RELATIVE_POSITION_IO_H_

#include <aixml/endnode.h>

class RelativePosition {
 public:
  RelativePosition() = default;
  RelativePosition(const std::string& origin)
      : inner_position_spanwise(EndnodeReadOnly<double>(origin + "position/inner_position/spanwise")),
        inner_position_chord_from(EndnodeReadOnly<double>(origin + "position/inner_position/chord/from")),
        inner_position_chord_to(EndnodeReadOnly<double>(origin + "position/inner_position/chord/to")),
        outer_position_spanwise(EndnodeReadOnly<double>(origin + "position/outer_position/spanwise")),
        outer_position_chord_from(EndnodeReadOnly<double>(origin + "position/outer_position/chord/from")),
        outer_position_chord_to(EndnodeReadOnly<double>(origin + "position/outer_position/chord/to")) {}
  EndnodeReadOnly<double> inner_position_spanwise;
  EndnodeReadOnly<double> inner_position_chord_from;
  EndnodeReadOnly<double> inner_position_chord_to;
  EndnodeReadOnly<double> outer_position_spanwise;
  EndnodeReadOnly<double> outer_position_chord_from;
  EndnodeReadOnly<double> outer_position_chord_to;

  void read(const node& xml) {
    inner_position_spanwise.read(xml);
    inner_position_chord_from.read(xml);
    inner_position_chord_to.read(xml);
    outer_position_spanwise.read(xml);
    outer_position_chord_from.read(xml);
    outer_position_chord_to.read(xml);
  }
};

#endif  // RELATIVE_POSITION_IO_H_