#include "tawWingDesignConfig.h"

taw::cantilever::WingDesignConfig::WingDesignConfig()
    : wing_design_mode(EndnodeReadOnly<std::string>("program_settings/modes/design_mode")),
      wing_mass_mode(
          EndnodeReadOnly<std::string>("program_settings/tube_and_wing/cantilever/calculation_methods/mass/method")),
      wing_configuration_mode(EndnodeReadOnly<std::string>("program_settings/tube_and_wing/wing_configuration")),
      wing_area_calculation_mode(EndnodeReadOnly<std::string>(
          "program_settings/tube_and_wing/cantilever/calculation_methods/wing_area/method")),
      user_wing_area(EndnodeReadOnly<double>(
          "program_settings/tube_and_wing/cantilever/calculation_methods/wing_area/parameters/mode_0/wing_area")),
      sweep_calculation_mode(
          EndnodeReadOnly<std::string>("program_settings/tube_and_wing/cantilever/calculation_methods/sweep/method")),
      user_sweep_angle_at_quarter_chord(EndnodeReadOnly<double>(
          "program_settings/tube_and_wing/cantilever/calculation_methods/sweep/parameters/mode_0/sweep_angle")),
      korn_technology_factor(EndnodeReadOnly<double>("program_settings/tube_and_wing/cantilever/calculation_methods/"
                                                     "sweep/parameters/mode_1/korn_technology_factor")),
      delta_drag_divergence_to_mach_design(
          EndnodeReadOnly<double>("program_settings/tube_and_wing/cantilever/calculation_methods/sweep/parameters/"
                                  "mode_1/delta_drag_divergence_to_mach_design")),
      taper_ratio_calculation_mode(EndnodeReadOnly<std::string>(
          "program_settings/tube_and_wing/cantilever/calculation_methods/taper_ratio/method")),
      user_taper_ratio(EndnodeReadOnly<double>(
          "program_settings/tube_and_wing/cantilever/calculation_methods/taper_ratio/parameters/mode_0/taper_ratio")),
      aspect_ratio_calculation_mode(EndnodeReadOnly<std::string>(
          "program_settings/tube_and_wing/cantilever/calculation_methods/aspect_ratio/method")),
      user_aspect_ratio(EndnodeReadOnly<double>(
          "program_settings/tube_and_wing/cantilever/calculation_methods/aspect_ratio/parameters/mode_0/aspect_ratio")),
      dihedral_calculation_mode(EndnodeReadOnly<std::string>(
          "program_settings/tube_and_wing/cantilever/calculation_methods/dihedral/method")),
      user_dihedral(EndnodeReadOnly<double>(
          "program_settings/tube_and_wing/cantilever/calculation_methods/dihedral/parameters/mode_0/dihedral_angle")),
      dihedral_limitation_mode(
          EndnodeReadOnly<std::string>("program_settings/tube_and_wing/cantilever/calculation_methods/dihedral/"
                                       "parameters/mode_1/dihedral_limitation")),
      relative_kink_position_calculation_mode(EndnodeReadOnly<std::string>(
          "program_settings/tube_and_wing/cantilever/calculation_methods/relative_kink_position/method")),
      user_relative_kink(EndnodeReadOnly<double>("program_settings/tube_and_wing/cantilever/calculation_methods/"
                                                 "relative_kink_position/parameters/mode_0/relative_kink_position")),
      user_max_inner_trailing_edge_sweep(
          EndnodeReadOnly<double>("program_settings/tube_and_wing/cantilever/calculation_methods/"
                                  "relative_kink_position/parameters/mode_0/maximum_inner_trailing_edge_sweep")),
      track_based_initial_relative_kink(
          EndnodeReadOnly<double>("program_settings/tube_and_wing/cantilever/calculation_methods/"
                                  "relative_kink_position/parameters/mode_1/initial_relative_kink_position")),
      track_based_max_inner_trailing_edge_sweep(
          EndnodeReadOnly<double>("program_settings/tube_and_wing/cantilever/calculation_methods/"
                                  "relative_kink_position/parameters/mode_1/maximum_inner_trailing_edge_sweep")),
      wing_profile_and_thickness_calculation_mode(
          EndnodeReadOnly<std::string>("program_settings/tube_and_wing/cantilever/calculation_methods/"
                                       "wing_profile_and_thickness_distribution/method")),
      torenbeek_jenkinson_wing_profile(
          EndnodeReadOnly<std::string>("program_settings/tube_and_wing/cantilever/calculation_methods/"
                                       "wing_profile_and_thickness_distribution/parameters/mode_1/wing_profile")),
      max_thickness_to_chord_ratio(EndnodeReadOnly<double>(
          "program_settings/tube_and_wing/cantilever/calculation_methods/wing_profile_and_thickness_distribution/"
          "parameters/mode_1/max_thickness_to_chord_ratio")),
      airfoil_critical_factor(
          EndnodeReadOnly<double>("program_settings/tube_and_wing/cantilever/calculation_methods/"
                                  "wing_profile_and_thickness_distribution/parameters/mode_1/airfoil_critical_factor")),
      control_device_mode(EndnodeReadOnly<std::string>(
          "program_settings/tube_and_wing/cantilever/calculation_methods/control_devices/method")),
      high_lift_device_type_leading_edge(
          EndnodeReadOnly<std::string>("program_settings/tube_and_wing/cantilever/calculation_methods/control_devices/"
                                       "parameters/mode_1/high_lift_device_type_leading_edge")),
      high_lift_device_type_trailing_edge(
          EndnodeReadOnly<std::string>("program_settings/tube_and_wing/cantilever/calculation_methods/control_devices/"
                                       "parameters/mode_1/high_lift_device_type_trailing_edge")),
      spars_mode(
          EndnodeReadOnly<std::string>("program_settings/tube_and_wing/cantilever/calculation_methods/spars/method")),
      flops_fstrt(EndnodeReadOnly<double>(
          "program_settings/tube_and_wing/cantilever/calculation_methods/mass/parameters/mode_0/fstrt")),
      flops_faert(EndnodeReadOnly<double>(
          "program_settings/tube_and_wing/cantilever/calculation_methods/mass/parameters/mode_0/faert")),
      flops_fcomp(EndnodeReadOnly<double>(
          "program_settings/tube_and_wing/cantilever/calculation_methods/mass/parameters/mode_0/fcomp")),
      flops_technology_factor(EndnodeReadOnly<double>(
          "program_settings/tube_and_wing/cantilever/calculation_methods/mass/parameters/mode_0/technology_factor")),
      chiozzotto_technology_factor(EndnodeReadOnly<double>(
          "program_settings/tube_and_wing/cantilever/calculation_methods/mass/parameters/mode_1/technology_factor")),
      chiozzotto_material(EndnodeReadOnly<std::string>(
          "program_settings/tube_and_wing/cantilever/calculation_methods/mass/parameters/mode_1/material")),
      common_airfoil_data_path(EndnodeReadOnly<std::string>("module_configuration_file/program_settings/additional_directory_paths/common_airfoil_data_path")) {}

void taw::cantilever::WingDesignConfig::read(const node& xml) {
  wing_design_mode.read(xml);
  wing_mass_mode.read(xml);
  wing_configuration_mode.read(xml);
  wing_area_calculation_mode.read(xml);
  user_wing_area.read(xml);
  sweep_calculation_mode.read(xml);
  user_sweep_angle_at_quarter_chord.read(xml);
  korn_technology_factor.read(xml);
  delta_drag_divergence_to_mach_design.read(xml);
  taper_ratio_calculation_mode.read(xml);
  user_taper_ratio.read(xml);
  aspect_ratio_calculation_mode.read(xml);
  user_aspect_ratio.read(xml);
  dihedral_calculation_mode.read(xml);
  user_dihedral.read(xml);
  dihedral_limitation_mode.read(xml);
  relative_kink_position_calculation_mode.read(xml);
  user_relative_kink.read(xml);
  user_max_inner_trailing_edge_sweep.read(xml);
  track_based_initial_relative_kink.read(xml);
  track_based_max_inner_trailing_edge_sweep.read(xml);
  wing_profile_and_thickness_calculation_mode.read(xml);
  torenbeek_jenkinson_wing_profile.read(xml);
  max_thickness_to_chord_ratio.read(xml);
  airfoil_critical_factor.read(xml);
  control_device_mode.read(xml);
  high_lift_device_type_leading_edge.read(xml);
  high_lift_device_type_trailing_edge.read(xml);
  spars_mode.read(xml);
  flops_fstrt.read(xml);
  flops_faert.read(xml);
  flops_fcomp.read(xml);
  flops_technology_factor.read(xml);
  chiozzotto_technology_factor.read(xml);
  chiozzotto_material.read(xml);
  common_airfoil_data_path.read(xml);

  // Read user wing profiles thickness and half span position
  if (user_wing_profiles.empty()) {
    node* result;
    int to_count = 0;
    do {
      result = xml.find(
          "program_settings/tube_and_wing/cantilever/calculation_methods/wing_profile_and_thickness_distribution/"
          "parameters/mode_0/wing_profile_and_thickness@" +
          std::to_string(to_count));
      to_count++;
    } while (result != nullptr);
    to_count--;
    for (int i = 0; i < to_count; ++i) {
      std::string id = std::to_string(i);
      user_wing_profiles.push_back(EndnodeReadOnly<std::string>(
          "program_settings/tube_and_wing/cantilever/calculation_methods/wing_profile_and_thickness_distribution/"
          "parameters/mode_0/wing_profile_and_thickness@" +
          id + "/wing_profile"));
      user_thickness_to_chord.push_back(EndnodeReadOnly<double>(
          "program_settings/tube_and_wing/cantilever/calculation_methods/wing_profile_and_thickness_distribution/"
          "parameters/mode_0/wing_profile_and_thickness@" +
          id + "/thickness_to_chord/ratio"));
      user_eta.push_back(EndnodeReadOnly<double>(
          "program_settings/tube_and_wing/cantilever/calculation_methods/wing_profile_and_thickness_distribution/"
          "parameters/mode_0/wing_profile_and_thickness@" +
          id + "/thickness_to_chord/at_half_span"));
      user_wing_profiles[i].read(xml);
      user_thickness_to_chord[i].read(xml);
      user_eta[i].read(xml);
      user_wing_profiles_and_thickness_vector.push_back(
          {user_eta[i].value(), user_thickness_to_chord[i].value(), user_wing_profiles[i].value()});
    }
  }

  // read user defined control surfaces
  if (user_defined_control_devices.empty()) {
    node* result;
    int to_count = 0;
    do {
      result = xml.find(
          "program_settings/tube_and_wing/cantilever/calculation_methods/control_devices/"
          "parameters/mode_0/control_device@" +
          std::to_string(to_count));
      to_count++;
    } while (result != nullptr);
    to_count--;
    for (int i = 0; i < to_count; ++i) {
      user_defined_control_devices.push_back(
          ControlDevice("program_settings/tube_and_wing/cantilever/calculation_methods/control_devices/"
                        "parameters/mode_0/control_device@" +
                        std::to_string(i) + "/"));
      user_defined_control_devices.back().read(xml);
    }
  }
  // read user defined spars
  if (user_defined_spars.empty()) {
    node* result;
    int to_count = 0;
    do {
      result = xml.find(
          "program_settings/tube_and_wing/cantilever/calculation_methods/spars/"
          "parameters/mode_0/spar@" +
          std::to_string(to_count));
      to_count++;
    } while (result != nullptr);
    to_count--;
    for (int i = 0; i < to_count; ++i) {
      user_defined_spars.push_back(
          Spar("program_settings/tube_and_wing/cantilever/calculation_methods/spars/"
               "parameters/mode_0/spar@" +
               std::to_string(i) + "/"));
      user_defined_spars.back().read(xml);
    }
  }
}
